=========
modbus.py
=========

..
  .. automodule:: modbus
..
.. .. autoclass:: modbus.Modbus
..    :no-index:

Modbus class
============
.. autoclass:: modbus.Modbus
    :members:
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

Exceptions
==========
.. autoclass:: modbus.ModbusError
.. autoclass:: modbus.SlaveExceptionError
.. autoclass:: modbus.IllegalRequestError
.. autoclass:: modbus.MasterReportedError
.. autoclass:: modbus.NoResponseError
.. autoclass:: modbus.InvalidResponseError

  Exceptions inherited from pyserial
----------------------------------
.. autoclass:: serial.SerialException
.. autoclass:: serial.PortNotOpenError
.. autoclass:: serial.SerialTimeoutException
